@@ -173,9 +173,7 @@ class SnapTradeAPIClient:
         endpoint_name = "user_login_redirect_uri"
 
         initial_query_params = dict(userId=user_id, userSecret=user_secret)
-        query_params = self.prepare_query_params(
-            endpoint_name, initial_params=initial_query_params
-        )
+        query_params = self.prepare_query_params(endpoint_name, initial_params=initial_query_params)
 
         data = dict()
         if broker:
